##  Displaying SAP Suggestions
To display SAP suggestions in a report, use the toggles in the SAP Suggestions menu on the report page. You can display suggestions for AI agents, applications, or both.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio338f50e7f99845bd8f3dc2d851f3e75e_LowRes.png)
Selecting SAP Suggestions to Display in a Report
